nullFunction <- function() {}

maxElements <- 48

generateStakeholderTypes <- function() {
  
  plotData <- list()
  plotNames <- list()
  plotValues <- list()
  plotOrders <- list()
  plotFunctions <- list()
  
  plotNames[['Stakeholder.types']] <- ''
  plotFunctions[['Stakeholder.types']] <- function(plotTitle) {
    values <- c(1,6,41)
    categories <- c("Non-technical", "Technical and non-technical", "Technical")
    plot <- barplot(values, names.arg=categories, main=plotTitle, cex.main=plotData[['fontSize']], xlim=c(0, maxElements + 5), cex=plotData[['smallFontSize']], cex.names=plotData[['fontSize']], horiz=TRUE)
    text(x=values + 2, y = plot, labels=as.factor(values), xpd=TRUE, cex=plotData[['fontSize']], col = "black")
  }
  
  plotData[['plotNames']] <- plotNames
  plotData[['plotValues']] <- plotValues
  plotData[['plotOrders']] <- plotOrders
  plotData[['plotFunctions']] <- plotFunctions
  
  # here we define the layout of the resulting plots matrix
  plotData[['numColumns']] <- 1
  plotData[['numRows']] <- 1
  
  # here we define the size and margins of the pdf being produced
  plotData[['xSize']] <- 20
  plotData[['ySize']] <- 3
  plotData[['margin']] <- 3
  plotData[['marginLeft']] <- 35
  
  plotData[['fontSize']] <- 2
  plotData[['smallFontSize']] <- 2
  
  # the file name of the pdf being produced
  plotData[['fileName']] <- "../papers/journalPaper/figures/stakeholder_types.pdf"
  
  plotData[['plotAdditionalFacets']] <- nullFunction
  
  return(plotData)
}

generateAwarenessLevel <- function() {
  
  plotData <- list()
  plotNames <- list()
  plotValues <- list()
  plotOrders <- list()
  plotFunctions <- list()
  
  plotNames[['Workspace.awareness.score']] <- ''
  plotFunctions[['Workspace.awareness.score']] <- function(plotTitle) {
    values <- c(29,8,11)
    categories <- c("Low", "Medium", "High")
    plot <- barplot(values, names.arg=categories, main=plotTitle, cex.main=plotData[['fontSize']], xlim=c(0, maxElements + 5), cex=plotData[['smallFontSize']], cex.names=plotData[['fontSize']], horiz=TRUE)
    text(x=values + 1, y = plot, labels=as.factor(values), xpd=TRUE, cex=plotData[['fontSize']], col = "black")
  }
  
  plotData[['plotNames']] <- plotNames
  plotData[['plotValues']] <- plotValues
  plotData[['plotOrders']] <- plotOrders
  plotData[['plotFunctions']] <- plotFunctions
  
  # here we define the layout of the resulting plots matrix
  plotData[['numColumns']] <- 1
  plotData[['numRows']] <- 1
  
  # here we define the size and margins of the pdf being produced
  plotData[['xSize']] <- 20
  plotData[['ySize']] <- 3
  plotData[['margin']] <- 3
  plotData[['marginLeft']] <- 35
  
  plotData[['fontSize']] <- 2
  plotData[['smallFontSize']] <- 2
  
  # the file name of the pdf being produced
  plotData[['fileName']] <- "../papers/journalPaper/figures/workspace_awareness_score.pdf"
  
  plotData[['plotAdditionalFacets']] <- nullFunction
  
  return(plotData)
}


############# DO NOT CHANGE ANYTHING BELOW THIS LINE ############# 

# here we select which data frame is containing all the data
dataSource <- DataExtractionCollaborative

# separator used in categorical variables with multiple values
separator <- ','

df <- dataSource

#plotData <- generateStakeholderTypes()
plotData <- generateAwarenessLevel()

library(splitstackshape)
library(plyr)
dt2 <- cSplit(df, splitCols=names(df), sep=separator, direction="long")
dt2 <- dt2[!duplicated(dt2), ]

ind <- apply(dt2, 1, function(x) all(is.na(x)))
dt2 <- dt2[ !ind, ]

index = 1
for(i in 1:nrow(dt2)) {
  row <- dt2[i,]
  if(is.na(row$ID)) {
    dt2[[i,1]] <- dt2[[i-1,1]]
  } else {
    index <- i
  }
}

pdf(plotData[['fileName']], width=plotData[['xSize']], height=plotData[['ySize']])
par(mar=c(plotData[['margin']], plotData[['marginLeft']], plotData[['margin']], plotData[['margin']]))
par(mfrow=c(plotData[['numRows']], plotData[['numColumns']]))
par(las=1)

reorderCounts <- function(arr, v) {
  result <- c()
  for(i in 1:length(arr)) {
    result[i] <- arr[plotData[['plotOrders']][[v]][i]]
  }
  return(result)
}

for(i in indexes) {
  var <- names(df)[i]
  if(!is.null(plotData[['plotNames']][[var]])) {
    plotTitle <- plotData[['plotNames']][[var]]
    if(!is.null(plotData[['plotFunctions']][[var]])) {
      plotData[['plotFunctions']][[var]](plotTitle)
    } else {
      toPlot <- as.factor(dt2[[var]])
      if(!is.null(plotData[['plotValues']][[var]])) {
        toPlot <- revalue(toPlot, plotData[['plotValues']][[var]])
        if(!is.null(plotData[['plotOrders']][[var]])) {
          toPlot <- factor(toPlot,levels(toPlot)[plotData[['plotOrders']][[var]]])
        }
      }
      counts <- count(dt2, var)$freq[1:length(count(dt2, var)$freq)-1]
      if(!is.null(plotData[['plotOrders']][[var]])) {
        counts <- reorderCounts(counts, var)
      }
      counts2 <- count(dt2, var)$freq + 2.4
      if(!is.null(plotData[['plotOrders']][[var]])) {
        counts2 <- reorderCounts(counts2, var)
      }
      plot <- plot(toPlot, main=plotTitle, cex.main=plotData[['fontSize']], xlim=c(0, nrow(df)+5), cex=plotData[['smallFontSize']], cex.names=plotData[['fontSize']], horiz=TRUE)
      text(x=counts2, y = plot, label = counts, cex = plotData[['fontSize']], col = "black")
      print(paste(plotTitle, " - plotted")) 
    }
  }
}

dev.off()
